@@ -20,6 +20,7 @@
 #include "threading/ConditionVariable.h"
 #include "threading/Thread.h"
 #include "vm/NativeObject.h"
+#include "vm/BigIntType.h"
 
 namespace js {
 
@@ -119,6 +120,7 @@ IsNurseryAllocable(AllocKind kind)
         false,     /* AllocKind::FAT_INLINE_ATOM */
         false,     /* AllocKind::ATOM */
         false,     /* AllocKind::SYMBOL */
+        false,     /* AllocKind::BIGINT */
         false,     /* AllocKind::JITCODE */
         false,     /* AllocKind::SCOPE */
         false,     /* AllocKind::REGEXP_SHARED */
@@ -158,6 +160,7 @@ IsBackgroundFinalized(AllocKind kind)
         true,      /* AllocKind::FAT_INLINE_ATOM */
         true,      /* AllocKind::ATOM */
         true,      /* AllocKind::SYMBOL */
+        true,      /* AllocKind::BIGINT */
         false,     /* AllocKind::JITCODE */
         true,      /* AllocKind::SCOPE */
         true,      /* AllocKind::REGEXP_SHARED */
