@@ -26,7 +26,7 @@ public:
     NS_DECL_NSIREQUESTOBSERVER
     NS_DECL_NSISTREAMLISTENER
 
-    MOZ_MUST_USE bool Init(const uint32_t& aArgs);
+    [[nodiscard]] bool Init(const uint32_t& aArgs);
 
 private:
     ~DataChannelParent();
